@@ -85,8 +85,8 @@ enum file_ops {
     op_file_directory_p,
     op_file_symlink_p,
     op_file_owner_p,
-    op_file_gid_p,
-    op_file_uid_p,
+    op_file_gid,
+    op_file_uid,
     op_file_nlinks,
     op_file_size,
     op_file_modes,
@@ -124,7 +124,7 @@ typedef struct rep_struct_struct rep_struct;
 struct rep_struct_struct {
     repv car;
     rep_struct *next;
-    repv name;
+  repv name; /* symbol, not string */
     repv inherited;	/* exported symbols that have no local binding */
     int total_buckets, total_bindings;
     rep_struct_node **buckets;
